########
REANA DB
########

.. image:: https://img.shields.io/pypi/pyversions/reana-db.svg
      :target: https://pypi.org/pypi/reana-db

.. image:: https://github.com/reanahub/reana-db/workflows/CI/badge.svg
      :target: https://github.com/reanahub/reana-db/actions

.. image:: https://readthedocs.org/projects/reana-db/badge/?version=latest
      :target: https://reana-db.readthedocs.io/en/latest/?badge=latest

.. image:: https://codecov.io/gh/reanahub/reana-db/branch/master/graph/badge.svg
   :target: https://codecov.io/gh/reanahub/reana-db

.. image:: https://badges.gitter.im/Join%20Chat.svg
      :target: https://gitter.im/reanahub/reana?utm_source=badge&utm_medium=badge&utm_campaign=pr-badge

.. image:: https://img.shields.io/github/license/reanahub/reana-db.svg
      :target: https://github.com/reanahub/reana-db/blob/master/LICENSE

.. image:: https://img.shields.io/badge/code%20style-black-000000.svg
   :target: https://github.com/psf/black

About
=====

REANA-DB is a component of the `REANA
<http://www.reana.io/>`_ reusable analysis platform.
It contains REANA database models and utilities.

Features
========

- database persistence for REANA system
- database models and utilities
- database upgrades and migrations

Usage
=====

The detailed information on how to install and use REANA can be found in
`docs.reana.io <https://docs.reana.io>`_.

Useful links
============

- `REANA project home page <http://www.reana.io/>`_
- `REANA user documentation <https://docs.reana.io>`_
- `REANA user support forum <https://forum.reana.io>`_

- `REANA-DB releases <https://reana-db.readthedocs.io/en/latest#changes>`_
- `REANA-DB developer documentation <https://reana-db.readthedocs.io/>`_
- `REANA-DB known issues <https://github.com/reanahub/reana-db/issues>`_
- `REANA-DB source code <https://github.com/reanahub/reana-db>`_
